==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/speech/translations/speech_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Konuşma</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Uyarılar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Konuşulan harflerin maksimum sayısı</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Mesaj çok uzun (erkek)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Mesaj çok uzun (kadın)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekans</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Ana frekans</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodi</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Ses sistemi</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dsp aygıtı</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt sentezleyici (dsp gerektirir)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Konuşma programı</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Bir yazı oku</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Erkek formatı</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Kadın formatı</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/speech/translations/speech_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Konuşma</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Uyarılar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Konuşulan harflerin maksimum sayısı</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Mesaj çok uzun (erkek)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Mesaj çok uzun (kadın)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekans</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Ana frekans</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodi</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Ses sistemi</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dsp aygıtı</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt sentezleyici (dsp gerektirir)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Konuşma programı</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Bir yazı oku</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Erkek formatı</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Kadın formatı</translation>
    </message>
</context>
</TS>
